@@ -21,15 +21,58 @@ import shutil
 import datetime
 import hashlib
 import zipfile
+import platform
 
 from django.core.management.base import BaseCommand
 
 from Iuppiter.Util import run
 from Zephyrus.boilerplate.management.commands import (
     PROJECT_MASHINES_DIR, PROJECT_MASHINES_ZIP, ROOT_DIR_PATH, 
-    PROJECT_VIRTUALENV_DIR)
+    PROJECT_VIRTUALENV_DIR, PROJECT_ENV_REQUIREMENTS, PROJECT_ENV_SCRIPT)
 from Zephyrus.boilerplate.management.commands import createLogger  
 
+def createEnv(version):
+    if not os.path.isdir(PROJECT_VIRTUALENV_DIR):
+        os.mkdir(PROJECT_VIRTUALENV_DIR)
+    
+    envPath = os.path.join(PROJECT_VIRTUALENV_DIR, "Env%s" % version)
+
+    # windows
+    if 'Windows' in platform.system(): 
+        pythonPath =  os.path.join(envPath, 'Scripts', 'python.exe')
+        cwdPath =  os.path.join(envPath, 'Scripts')
+        scriptPath = os.path.join(PROJECT_VIRTUALENV_DIR, 'CreateEnv.bat')
+    else:
+        pythonPath =  os.path.join(envPath, 'bin', 'python')
+        cwdPath =  os.path.join(envPath, 'bin')
+        scriptPath = os.path.join(PROJECT_VIRTUALENV_DIR, 'CreateEnv.sh')
+
+    # requirements
+    requirementPath = os.path.join(
+        PROJECT_VIRTUALENV_DIR, 'REQUIREMENTS_%s.txt' % version)
+
+    if not os.path.isdir(envPath):
+        # copy file
+        if not os.path.isfile(scriptPath):
+            shutil.copyfile(PROJECT_ENV_SCRIPT, scriptPath)
+
+        #  windows
+        if not os.path.isfile(requirementPath):
+            shutil.copyfile(
+                PROJECT_ENV_REQUIREMENTS.replace("[VERSION]", version), 
+                requirementPath)
+
+        # create env
+        #  windows
+        if 'Windows' in platform.system(): 
+            run("CreateEnv.bat %s" % version, 
+                shell=True, cwd=PROJECT_VIRTUALENV_DIR)
+        else:
+            run("chmod +x CreateEnv.sh && ./CreateEnv.sh %s" % version, 
+                shell=True, cwd=PROJECT_VIRTUALENV_DIR)
+
+    return (envPath, pythonPath)
+
 class Command(BaseCommand):
 
     help = 'Start build all zip of template to dst folder.'
@@ -47,7 +90,7 @@ class Command(BaseCommand):
             help="build all template for TemplateShop.")
         parser.add_argument(
             '-c', '--cmsVersion', 
-            type=str, default="3.5.1",
+            type=str, default="3.5.2",
             help="CMS version for products.")
         
 
@@ -139,23 +182,4 @@ class Command(BaseCommand):
         return templateDir
 
     def createEnv(self, version):
-        if not os.path.isdir(PROJECT_VIRTUALENV_DIR):
-            os.mkdir(PROJECT_VIRTUALENV_DIR)
-        
-        envPath = os.path.join(PROJECT_VIRTUALENV_DIR, "Env%s" % version)
-
-        # windows
-        pythonPath =  os.path.join(envPath, 'Scripts', 'python.exe')
-        cwdPath =  os.path.join(envPath, 'Scripts')
-
-        if not os.path.isdir(envPath):
-            # create env
-            run("virtualenv Env%s" % version, 
-                shell=True, cwd=PROJECT_VIRTUALENV_DIR)
-            # install pkg
-            run("activate && pip install Zephyrus", shell=True, cwd=cwdPath)
-
-        run("activate && pip install -U django-cms==%s --no-deps" % version, 
-            shell=True, cwd=cwdPath)
-
-        return (envPath, pythonPath)
+        return createEnv(version)
